<?php
namespace Geral\Repositories;

class Posestatu extends \Doctrine\ORM\EntityRepository{

    public function consultaPosicaoAtualEstoque($dataInventario, $filial, $nrorg){
        $sql = "SELECT PE.CDFILIAL, TO_DATE(:P_DTINVFISCFIL), PE.CDPRODUTO,
                       ROUND(SUM(PE.QTTOTALESTOQ), 3) AS QTPRODINVFIL,
                       ROUND((SUM(PE.VRTOTALESTOQ)/SUM(PE.QTTOTALESTOQ)), 5) AS VRUNITINVFIL,
                       ROUND(SUM(PE.VRTOTALESTOQ), 2) AS VRTOTAINVFIL
                  FROM POSESTATU PE
                 WHERE PE.CDFILIAL     = :P_CDFILIAL
                   AND PE.QTTOTALESTOQ <> 0
                   AND PE.NRORG        = :P_NRORG
                 GROUP BY PE.CDFILIAL, PE.CDPRODUTO
                HAVING SUM(PE.QTTOTALESTOQ) > 0";

        $params = array(
            "P_DTINVFISCFIL" => $dataInventario,
            "P_CDFILIAL"     => $filial,
            "P_NRORG"        => $nrorg,
        );

        $entityManager = $this->getEntityManager();
        $result        = $entityManager->getConnection()->fetchAll($sql, $params);
        return $result ? $result : false;
    }

    public function consultaProdutosPosicaoEstoqueAtual($filial, $almoxarifado, $local, $produto_ini, $produto_fin,
                                                        $data, $dataMaisUm, $tcdalmoxarife = null,
                                                        $tcdlocalestoq = null){
        if (!$almoxarifado)
            $tcdalmoxarife = 'T';
        if (!$local)
            $tcdlocalestoq = 'T';

        $sql = <<<SQL
                        SELECT P.CDFILIAL, P.CDPRODUTO, CDALMOXARIFE, CDLOCALESTOQ, NRLOTEESTQ, NRSUBLOTE, (DTULTMOVIMEN - 1) as DTULTMOVIMEN
                        FROM POSESTATU P, PRODUTO A
                        WHERE CDFILIAL = :P_CDFILIAL   AND
                              DTULTMOVIMEN >= (:P_DATAINIMAISUM)   AND
                             (CDALMOXARIFE = NVL(:P_CDALMOXARIFE,CDALMOXARIFE) OR :P_TCDALMOXARIFE = 'T') AND
                             (CDLOCALESTOQ = NVL(:P_CDLOCALESTOQ,CDLOCALESTOQ) OR :P_TCDLOCALESTOQ = 'T') AND
                             (P.CDPRODUTO   = A.CDPRODUTO) AND
                             (A.CDARVPROD BETWEEN :P_PRODINI AND :P_PRODFIM)
                        MINUS

                        SELECT CDFILIAL, IL.CDPRODMOVI, CDALMOXARIFE, CDLOCALESTOQ, NRLOTEESTQ, NRSUBLOTE, DTLANCMOVI
                        FROM ITLANCTOEST IL, PRODUTO PR
                        WHERE CDFILIMOVI = :P_CDFILIAL   AND
                              DTLANCMOVI >= :P_DATAINI  AND
                              (IL.CDALMOXARIFE = NVL(:P_CDALMOXARIFE,IL.CDALMOXARIFE) OR :P_TCDALMOXARIFE = 'T') AND
                              (IL.CDLOCALESTOQ = NVL(:P_CDLOCALESTOQ,IL.CDLOCALESTOQ) OR :P_TCDLOCALESTOQ = 'T') AND
                              (IL.CDPRODMOVI   = PR.CDPRODUTO                             ) AND
                              (PR.CDARVPROD BETWEEN :P_PRODINI AND :P_PRODFIM             ) AND
                              (NVL(IL.IDEVOLESTOQ,'S') = 'S'                              )

                        ORDER BY CDPRODUTO
SQL;

        $params = array(
            "P_PRODINI"       => $produto_ini,
            "P_PRODFIM"       => $produto_fin,
            "P_DATAINI"       => $data,
            "P_DATAINIMAISUM" => $dataMaisUm,
            "P_CDFILIAL"      => $filial,
            "P_CDALMOXARIFE"  => $almoxarifado,
            "P_TCDALMOXARIFE" => $tcdalmoxarife,
            "P_CDLOCALESTOQ"  => $local,
            "P_TCDLOCALESTOQ" => $tcdlocalestoq,
        );

        try{
            return self::getEntityManager()->getConnection()->fetchAll($sql, $params);
        } catch (\Exception $e){
            throw $e;
        }
    }

    public function deletaPosicaoEstoqueAtual($filial, $almoxarifado, $local, $nrlote, $nrsublote, $cdproduto){
        $sql = <<<SQL
                        DELETE
                        FROM POSESTATU P
                        WHERE
                           (P.CDFILIAL = :P_CDFILIAL) AND
                           (P.CDALMOXARIFE = :P_CDALMOXARIFE) AND
                           (P.CDLOCALESTOQ = :P_CDLOCALESTOQ) AND
                           (P.NRLOTEESTQ  = :P_NRLOTEESTQ) AND
                           (P.NRSUBLOTE = :P_NRSUBLOTE) AND
                           (P.CDPRODUTO = :P_CDPRODUTO)
SQL;

        $params = array(
            "P_CDFILIAL"     => $filial,
            "P_CDALMOXARIFE" => $almoxarifado,
            "P_CDLOCALESTOQ" => $local,
            "P_NRLOTEESTQ"   => $nrlote,
            "P_NRSUBLOTE"    => $nrsublote,
            "P_CDPRODUTO"    => $cdproduto,
        );

        try{
            return self::getEntityManager()->getConnection()->executeQuery($sql, $params);
        } catch (\Exception $e){
            throw $e;
        }
    }

    public function deletaPosicaoEstoquePorProduto($filial, $produto){

        $sql = <<<SQL
            DELETE FROM POSESTATU
            WHERE (CDFILIAL  = :P_CDFILIAL)  AND
                  (CDPRODUTO = :P_CDPRODUTO)
SQL;

        $params = array(
            "P_CDFILIAL" => $filial,
            "P_CDPRODUTO" => $produto,
        );

        try{
            return self::getEntityManager()->getConnection()->executeQuery($sql, $params);
        } catch(\Exception $e) {
            throw $e;
        }
    }
}