/*
  LOG_PARGRUPOFISC_TPFATURFIS responsvel por gravar as informaes
  na tabela LOGOPERA a partir dos registros que forem includos,
  excludos e alterados na tabela TPFATURFIS na tela de
  "Parmetros de Grupo Fiscal - Tipo de Gesto Fiscal"
  ou na tela de "Tipo de Gesto Fiscal"
  Criao: 02/05/2012
  Lucas Primo
*/

IF EXISTS (SELECT * FROM SYSOBJECTS O, SYSUSERS U
           WHERE O.NAME = 'LOG_PARGRUPOFISC_TPFATURFIS'
             AND TYPE   = 'TR'
             AND U.UID  = O.UID
             AND U.NAME = USER)
DROP TRIGGER LOG_PARGRUPOFISC_TPFATURFIS
GO

CREATE TRIGGER LOG_PARGRUPOFISC_TPFATURFIS
ON TPFATURFIS
FOR INSERT, UPDATE, DELETE
AS
  DECLARE  @V_CDFILLOGOPER  VARCHAR(4);
  DECLARE  @V_USUARIO       VARCHAR(40);
  DECLARE  @V_TIPO	    VARCHAR(1);
  DECLARE  @V_ITPESQ  	    VARCHAR(40);
  DECLARE  @V_DESC	    VARCHAR(300);
  DECLARE  @V_DTOPER	    DATETIME;
  DECLARE  @V_DSREMOTEADDR  VARCHAR(15);
  DECLARE  @V_DSREMOTEHOST  VARCHAR(15);
  DECLARE  @V_DSSERVERRDM   VARCHAR(20);
  DECLARE  @V_DSSERVMETHOD  VARCHAR(30);
  DECLARE  @V_DSREMOTEOPER  VARCHAR(12);

/*VARIVEIS DO CURSOR C_CURSOR*/

  DECLARE  @V_ID_COMANDO         VARCHAR(1);
  DECLARE  @V_CDTPFATURFIS_OLD   VARCHAR(10);
  DECLARE  @V_NMTPFATURFIS_OLD   VARCHAR(30);
  DECLARE  @V_CDGRUPOFISC_OLD    VARCHAR(10);

  DECLARE  @V_CDTPFATURFIS_NEW   VARCHAR(10);
  DECLARE  @V_NMTPFATURFIS_NEW   VARCHAR(30);
  DECLARE  @V_CDGRUPOFISC_NEW    VARCHAR(10);

BEGIN
   SET @V_TIPO = '0';
   SET @V_DESC = '';
   SET @V_CDFILLOGOPER = '';

   EXEC WEBTUNNING @P_DSREMOTEADDR = @V_DSREMOTEADDR OUTPUT,
                   @P_DSREMOTEHOST = @V_DSREMOTEHOST OUTPUT,
                   @P_DSSERVERRDM  = @V_DSSERVERRDM OUTPUT,
                   @P_DSSERVMETHOD = @V_DSSERVMETHOD OUTPUT,
                   @P_DSREMOTEOPER = @V_DSREMOTEOPER OUTPUT;

   EXEC NMUSUARIO @P_NMUSUARIO = @V_USUARIO OUTPUT;

   SET @V_USUARIO = ISNULL(@V_USUARIO, '');

   DECLARE C_CURSOR CURSOR FOR

   SELECT
     'D' IDCOMANDO,
         NULL,
         NULL,
         NULL,

         CDTPFATURFIS,
         NMTPFATURFIS,
         CDGRUPOFISC
   FROM
     DELETED
   WHERE
     --0 = (SELECT COUNT(1) FROM INSERTED)
     CDTPFATURFIS NOT IN (SELECT CDTPFATURFIS FROM INSERTED)

   UNION ALL

   SELECT
     'U' IDCOMANDO,
      INSERTED.CDTPFATURFIS,
      INSERTED.NMTPFATURFIS,
      INSERTED.CDGRUPOFISC,

      DELETED.CDTPFATURFIS,
      DELETED.NMTPFATURFIS,
      DELETED.CDGRUPOFISC
     FROM
      INSERTED,
      DELETED

   UNION ALL

   SELECT
      'I' IDCOMANDO,
      CDTPFATURFIS,
      NMTPFATURFIS,
      CDGRUPOFISC,

      NULL,
      NULL,
      NULL
   FROM
      INSERTED
   WHERE
      CDTPFATURFIS NOT IN (SELECT CDTPFATURFIS FROM DELETED);
      --0 = (SELECT COUNT(1) FROM DELETED);
   OPEN C_CURSOR;
   FETCH NEXT FROM C_CURSOR INTO @V_ID_COMANDO,
                                 @V_CDTPFATURFIS_NEW,
                                 @V_NMTPFATURFIS_NEW,
                                 @V_CDGRUPOFISC_NEW,
                                 @V_CDTPFATURFIS_OLD,
                                 @V_NMTPFATURFIS_OLD,
                                 @V_CDGRUPOFISC_OLD;

   WHILE (@@FETCH_STATUS = 0) BEGIN
      IF NOT (@V_USUARIO IS NULL) BEGIN

         IF @V_ID_COMANDO = 'D' BEGIN

            SET @V_DESC = @V_DESC + ' Tela=' + 'Tipo de Gesto Fiscal';
            IF @V_CDTPFATURFIS_OLD <> ' ' BEGIN
               SET @V_DESC = @V_DESC + ' Codigo=' + @V_CDTPFATURFIS_OLD;
            END;

            IF @V_NMTPFATURFIS_OLD <> ' '  BEGIN
               SET @V_DESC = @V_DESC + ' Desc=' + @V_NMTPFATURFIS_OLD;
            END;

            IF @V_CDGRUPOFISC_OLD <> ' ' BEGIN
               SET @V_DESC = @V_DESC + ' Grupo=' + @V_CDGRUPOFISC_OLD;
            END;

            SET @V_TIPO   = '3';
            SET @V_ITPESQ = @V_CDTPFATURFIS_OLD;
         END;
         IF @V_ID_COMANDO = 'U' /*UPDATING*/ BEGIN

            SET @V_DESC = @V_DESC + ' Aba=' + 'Tipo de Gesto Fiscal';
            IF (@V_CDTPFATURFIS_OLD) <> (@V_CDTPFATURFIS_NEW)   OR
               (@V_NMTPFATURFIS_OLD) <> (@V_NMTPFATURFIS_NEW)   OR
               ISNULL(@V_CDGRUPOFISC_OLD, 'N')  <> ISNULL(@V_CDGRUPOFISC_NEW, 'N') BEGIN

               IF (@V_CDTPFATURFIS_NEW IS NOT NULL) BEGIN
                  SET @V_DESC = @V_DESC + ' Codigo=' + @V_CDTPFATURFIS_NEW;
               END;

               IF (@V_NMTPFATURFIS_NEW IS NOT NULL) BEGIN
                  SET @V_DESC = @V_DESC + ' Desc=' + @V_NMTPFATURFIS_NEW;
               END;

               IF (@V_CDGRUPOFISC_NEW IS NOT NULL) BEGIN
                  SET @V_DESC = @V_DESC + ' Grupo=' + @V_CDGRUPOFISC_NEW;
               END;

               IF (@V_CDGRUPOFISC_NEW IS NULL) BEGIN
                  SET @V_DESC = @V_DESC + ' Grupo=' + '';
               END;

               SET @V_TIPO   = '2';
               SET @V_ITPESQ = @V_CDTPFATURFIS_OLD;
            END;
         END;

         IF @V_ID_COMANDO = 'I' BEGIN
            SET @V_DESC = @V_DESC + ' Tela=' + 'Tipo de Gesto Fiscal';
            IF (@V_CDTPFATURFIS_NEW IS NOT NULL) BEGIN
               SET @V_DESC = @V_DESC + ' Codigo=' + @V_CDTPFATURFIS_NEW;
            END;

            IF (@V_NMTPFATURFIS_NEW IS NOT NULL) BEGIN
               SET @V_DESC = @V_DESC + ' Desc=' + @V_NMTPFATURFIS_NEW;
            END;

            IF (@V_CDGRUPOFISC_NEW IS NOT NULL) BEGIN
               SET @V_DESC = @V_DESC + ' Grupo=' + @V_CDGRUPOFISC_NEW;
            END;

            SET @V_TIPO   = '1';

            SET @V_ITPESQ = @V_CDTPFATURFIS_NEW;
         END;

         IF @V_TIPO <> '0' BEGIN
            EXEC NMUSUARIO @V_USUARIO;
            IF NOT (@V_DESC IS NULL) BEGIN
               IF NOT (@V_USUARIO IS NULL) BEGIN
                  SET @V_DTOPER = GETDATE();

                  SET @V_DESC = SUBSTRING(@V_DESC, 1, 300);

                  INSERT INTO LOGOPERA
                     (NMTABELA,   DTOPERACAO, NMRESPOPER,
                      IDTIPOOPER, CDPESQITEM, DSOPERACAO,
                      DSRDMUSUOPER, DSENDUSUOPER, DSNMUSUOPER,
                      DSMETUSUOPER, CDORESPOPER, CDFILLOGOPER)
                  VALUES
                     ('PARGRUPOFISC',  @V_DTOPER, @V_USUARIO,
                      @V_TIPO,    @V_ITPESQ, @V_DESC,
                      @V_DSSERVERRDM, @V_DSREMOTEADDR, @V_DSREMOTEHOST,
                      @V_DSSERVMETHOD, @V_DSREMOTEOPER, @V_CDFILLOGOPER);
               END;
            END;
         END;

         FETCH NEXT FROM C_CURSOR INTO @V_ID_COMANDO,
                                       @V_CDTPFATURFIS_OLD,
                                       @V_NMTPFATURFIS_OLD,
                                       @V_CDGRUPOFISC_OLD,

                                       @V_CDTPFATURFIS_NEW,
                                       @V_NMTPFATURFIS_NEW,
                                       @V_CDGRUPOFISC_NEW;



      END;
   END;
   CLOSE      C_CURSOR;
   DEALLOCATE C_CURSOR;


END;
GO

-- VERSAO --
EXEC ATUVEROBJ 'LOG_PARGRUPOFISC_TPFATURFIS','5.42.000';
GO
